pub fn render(
tree: &DisplayTree,
config: &RenderConfig,
) -> Result<Bitmap, RenderError>Expand description
Render a display tree to a bitmap using the default backend.
pub fn render(
tree: &DisplayTree,
config: &RenderConfig,
) -> Result<Bitmap, RenderError>Render a display tree to a bitmap using the default backend.