DisplayRenderer

Struct DisplayRenderer 

pub struct DisplayRenderer<'a, B: RenderBackend> { /* private fields */ }
Renders a DisplayTree by implementing DisplayVisitor and forwarding drawing commands to a RenderBackend.

Implementations

Source

impl<'a, B: RenderBackend> DisplayRenderer<'a, B>

pub fn new( backend: &'a mut B, surface: &'a mut B::Surface, page_transform: Matrix, image_decoder: Option<&'a dyn ImageDecoder>, ) -> Self

Create a new renderer targeting the given backend and surface.

pub fn with_fallback_fonts(self, fonts: Vec<Arc<ResolvedFont>>) -> Self

Set fallback fonts to use when the primary font is missing a glyph.

pub fn with_forced_color_scheme(self, scheme: ColorScheme) -> Self

Set a forced color scheme for accessibility rendering.

pub fn with_per_feature_aa( self, text_aa: bool, path_aa: bool, image_aa: bool, ) -> Self

Set per-feature anti-aliasing flags.