pub struct RgbaColor {
pub r: u8,
pub g: u8,
pub b: u8,
pub a: u8,
}Expand description
An RGBA color value with 8 bits per component.
Fields
r: u8Red component.
g: u8Green component.
b: u8Blue component.
a: u8Alpha component (255 = fully opaque).
Implementations
Sourceimpl RgbaColor
impl RgbaColor
Sourcepub const TRANSPARENT: Self
pub const TRANSPARENT: Self
Fully transparent.
Sourcepub fn from_pdf_color(color: &Color, alpha: f32) -> Self
pub fn from_pdf_color(color: &Color, alpha: f32) -> Self
Convert a PDF color to RGBA.
The alpha parameter is in the range [0.0, 1.0].
Color components are interpreted based on the number of components:
- 1 component: DeviceGray
- 3 components: DeviceRGB
- 4 components: DeviceCMYK (simple subtractive conversion)
Sourcepub fn from_resolved_color(
color: &Color,
cs: &ResolvedColorSpace,
alpha: f32,
) -> Self
pub fn from_resolved_color( color: &Color, cs: &ResolvedColorSpace, alpha: f32, ) -> Self
Convert a color using a resolved color space to RGBA.
This handles advanced color spaces (CalGray, CalRGB, Lab, ICCBased, Indexed, Separation, DeviceN) by converting through intermediate device-independent steps to sRGB.